@@ -29,6 +29,7 @@ extern GtkEntryCompletion *completion;
 extern GNOMEInternetRadioLocatorStationInfo *stationinfo, *localstation;
 extern gchar *world_station_xml_filename;
 extern GstPlayer *player;
+extern ChamplainMarkerLayer *layer;
 
 typedef struct
 {
@@ -74,7 +75,6 @@ ChamplainMarkerLayer *
 create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **path)
 {
   ClutterActor *marker;
-  ChamplainMarkerLayer *layer;
   ClutterActor *layer_actor;
   ClutterColor orange = { 0xf3, 0x94, 0x07, 0xbb };
   LocationCallbackData callback_data;
@@ -107,6 +107,13 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
   /* champlain_path_layer_add_node (*path, CHAMPLAIN_LOCATION (marker)); */
   g_signal_connect(CHAMPLAIN_LOCATION(marker), "button-press", G_CALLBACK(marker_function), NULL);
 
+  marker = champlain_label_new_from_file ("icons/emblem-generic.png", NULL);
+  champlain_label_set_text (CHAMPLAIN_LABEL (marker), "Oslo, Norway");
+  champlain_location_set_location (CHAMPLAIN_LOCATION (marker),59.9132694,10.7391112);
+  champlain_marker_layer_add_marker (layer, CHAMPLAIN_MARKER (marker));
+  /* champlain_path_layer_add_node (*path, CHAMPLAIN_LOCATION (marker)); */
+  g_signal_connect(CHAMPLAIN_LOCATION(marker), "button-press", G_CALLBACK(marker_function), NULL);
+
   marker = champlain_label_new_from_file ("icons/emblem-generic.png", NULL);
   champlain_label_set_text (CHAMPLAIN_LABEL (marker), "Washington, DC");
   champlain_location_set_location (CHAMPLAIN_LOCATION (marker), 38.8949549, -77.0366456);
