@@ -70,6 +70,8 @@ gchar *list_item_data_key ="list_item_data";
 
 GtkWidget *gnome_internet_radio_locator_app;
 GstPlayer *player;
+ChamplainMarkerLayer *layer;
+ClutterActor *marker;
 
 gchar *world_station_xml_filename, *local_station_xml_file;
 
@@ -113,21 +115,34 @@ mouse_click_cb (ClutterActor *actor, ClutterButtonEvent *event, ChamplainView *v
 {
 	GError **error;
 	gdouble lat, lon;
-	GeocodePlace *place;
-	GeocodeLocation *location;
-	GeocodeReverse *reverse;
-	const char *name;
+	GeocodePlace *place_city, *place_country;
+	GeocodeLocation *location_city;
+	GeocodeLocation *location_country;
+	GeocodeReverse *reverse_city, *reverse_country;
+	const char *name, *name_city, *name_country;
 	/* GeocodeForward *fwd; */
 	/* GList *list; */
 	/* GError **err; */
 	lon = champlain_view_x_to_longitude (view, event->x);
 	lat = champlain_view_y_to_latitude (view, event->y);
-	location = geocode_location_new (lat, lon, GEOCODE_LOCATION_ACCURACY_CITY);
-	reverse = geocode_reverse_new_for_location (location);
-	place = geocode_reverse_resolve (reverse, error);
-	name = geocode_place_get_town (place);
-	gtk_entry_set_text(GTK_ENTRY(input),(gchar *)name);
-	g_print ("Mouse click at: %f %f (%s)\n", lat, lon, name);
+	location_city = geocode_location_new (lat, lon, GEOCODE_LOCATION_ACCURACY_CITY);
+	location_country = geocode_location_new (lat, lon, GEOCODE_LOCATION_ACCURACY_COUNTRY);
+	reverse_city = geocode_reverse_new_for_location (location_city);
+	reverse_country = geocode_reverse_new_for_location (location_country);
+	place_city = geocode_reverse_resolve (reverse_city, error);
+	place_country = geocode_reverse_resolve (reverse_country, error);
+	name_city = geocode_place_get_town (place_city);
+	name_country = geocode_place_get_country (place_country);
+	marker = champlain_label_new_from_file ("icons/emblem-generic.png", NULL);
+	name = g_strconcat(name_city, ", ", name_country, NULL);
+	champlain_label_set_text (CHAMPLAIN_LABEL (marker), (gchar *)name);
+	champlain_location_set_location (CHAMPLAIN_LOCATION (marker), lat, lon);
+	if (g_strcmp0(name, NULL)) {
+		champlain_marker_layer_add_marker (layer, CHAMPLAIN_MARKER (marker));
+		gtk_entry_set_text(GTK_ENTRY(input),(gchar *)name);
+		g_signal_connect(CHAMPLAIN_LOCATION(marker), "button-press", G_CALLBACK(marker_function), NULL);
+	}
+	GNOME_INTERNET_RADIO_LOCATOR_DEBUG_MSG("Mouse click at: %f %f (%s)\n", lat, lon, name);
 	return TRUE;
 }
 
@@ -668,7 +683,6 @@ main (int argc,
 	GtkWidget *window;
 	GtkWidget *widget, *vbox, *bbox, *button, *viewport, *image;
 	ChamplainView *view;
-	ChamplainMarkerLayer *layer;
 	ClutterActor *scale;
 	ChamplainLicense *license_actor;
 	GtkListStore *model;
